@@ -3,7 +3,6 @@ Experimental format for TIA .ser files used by some FEI microscopes. See
 https://personal.ntu.edu.sg/cbb/info/TIAformat/index.html
 """
 
-
 from __future__ import annotations
 
 import os
@@ -123,9 +122,9 @@ def read_emi(filename):
     grp = root.find("ExperimentalDescription/Root")
 
     for elem in grp:
-        _emi[
-            "{} [{}]".format(elem.findtext("Label"), elem.findtext("Unit"))
-        ] = _parseEntry_emi(elem.findtext("Value"))
+        _emi["{} [{}]".format(elem.findtext("Label"), elem.findtext("Unit"))] = (
+            _parseEntry_emi(elem.findtext("Value"))
+        )
 
     # AcquireInfo
     grp = root.find("AcquireInfo")
@@ -390,7 +389,6 @@ class FormatSER(Format):
 class FormatSERimages(FormatSER):
     @staticmethod
     def understand(image_file):
-
         with FormatSER.open_file(image_file, "rb") as fh:
             fh.seek(18)
             nimages = struct.unpack("<I", fh.read(4))[0]
@@ -422,14 +420,12 @@ class FormatSERimages(FormatSER):
 class FormatSERstack(FormatMultiImage, FormatSER):
     @staticmethod
     def understand(image_file):
-
         with FormatSER.open_file(image_file, "rb") as fh:
             fh.seek(18)
             nimages = struct.unpack("<I", fh.read(4))[0]
         return nimages > 1
 
     def __init__(self, image_file, **kwargs):
-
         if not self.understand(image_file):
             raise IncorrectFormatError(self, image_file)
         FormatMultiImage.__init__(self, **kwargs)
