@@ -303,21 +303,36 @@ def set_detector_distance(detector, distance):
     """
     Set detector origin from distance along normal
     """
-    assert len(detector) == 1
-    normal = matrix.col(detector[0].get_normal())
-    origin = matrix.col(detector[0].get_origin())
-    d = origin.dot(normal)
-    x = origin - d * normal
-    origin = distance * normal + x
-    fast_axis = detector[0].get_fast_axis()
-    slow_axis = detector[0].get_slow_axis()
-    detector[0].set_frame(fast_axis, slow_axis, origin)
+    panels = list(detector)
+    if len(panels) > 1:
+        # If a multi-panel detector has a hierarchy, we will just update the
+        # root note. Otherwise check that all panels are at the same distance
+        # and share the same normal vector
+        try:
+            panels = [
+                detector.hierarchy(),
+            ]
+        except AttributeError:
+            dists = [p.get_distance() for p in panels]
+            norm_vecs = [p.get_normal() for p in panels]
+            assert all(v == norm_vecs[0] for v in norm_vecs[1:]) and all(
+                d == dists[0] for d in dists
+            )
+
+    for panel in panels:
+        normal = matrix.col(panel.get_normal())
+        origin = matrix.col(panel.get_origin())
+        d = origin.dot(normal)
+        x = origin - d * normal
+        origin = distance * normal + x
+        fast_axis = panel.get_fast_axis()
+        slow_axis = panel.get_slow_axis()
+        panel.set_frame(fast_axis, slow_axis, origin)
 
 
 def get_detector_projection_2d_axes(
     detector: Detector,
 ) -> tuple[list[Float2], list[Float2], list[Float2]]:
-
     """
     Project panel origins, fast and slow axes onto the best-fitting 2D plane.
     """
@@ -436,7 +451,6 @@ def get_panel_projection_2d_from_axes(
     slow_axis_2d: matrix.col,
     origin_2d: matrix.col,
 ) -> tuple[Float4, Float2]:
-
     """
     Gets translation and rotation required to project image_data from panel,
     based on axes given.
