@@ -242,7 +242,7 @@ class ExperimentListDict:
         loaded from the named file in the target directory.
 
         If any experiments point to a file in this way, the imageset is
-        loaded and the experiment is rewritted with an integer pointing
+        loaded and the experiment is rewritten with an integer pointing
         to the new ImageSet in the returned list.
 
         Returns:
@@ -284,7 +284,10 @@ class ExperimentListDict:
         self, imageset_data: dict, param: str
     ) -> tuple[str | None, Any]:
         """
-        Read a filename from an imageset dict and load if required.
+        Read a filename from an imageset dict and load if available. This is
+        used to load mask, gain, pedestal and offset maps. In some situations
+        (such as tests) these files are not available, in which case the
+        filename is kept but the data is None.
 
         Args:
             imageset_data: The dictionary holding imageset information
@@ -292,19 +295,24 @@ class ExperimentListDict:
 
         Returns:
             A tuple of (filename, data) where data has been loaded from
-            the pickle file. If there is no key entry then (None, None)
-            is returned. If the configuration parameter check_format is
-            False then (filename, None) will be returned.
+            the pickle file, or is None if the file is inaccessible. If there
+            is no key entry then ("", None) is returned.
         """
         if param not in imageset_data:
             return "", None
 
         filename = resolve_path(imageset_data[param], directory=self._directory)
-        if self._check_format and filename:
-            with open(filename, "rb") as fh:
-                return filename, pickle.load(fh, encoding="bytes")
+        data = None
+        if filename:
+            try:
+                with open(filename, "rb") as fh:
+                    data = pickle.load(fh, encoding="bytes")
+            except OSError:
+                pass
+        else:
+            filename = ""
 
-        return filename or "", None
+        return filename, data
 
     def _imageset_from_imageset_data(self, imageset_data, models):
         """Make an imageset from imageset_data - help with refactor decode."""
@@ -326,6 +334,14 @@ class ExperimentListDict:
         dx_filename, dx = self._load_pickle_path(imageset_data, "dx")
         dy_filename, dy = self._load_pickle_path(imageset_data, "dy")
 
+        # If dx, dy maps are expected then they must be loaded even when
+        # self._check_format == False, because they affect the operation of
+        # programs (dials.index, dials.refine) that do not need the image data.
+        if (dx_filename or dy_filename) and not all((dx, dx)):
+            raise RuntimeError(
+                f"dx ({dx_filename}) and dy ({dy_filename}) maps are expected"
+            )
+
         if imageset_data["__id__"] == "ImageSet":
             imageset = self._make_stills(imageset_data, format_kwargs=format_kwargs)
         elif imageset_data["__id__"] == "ImageGrid":
@@ -400,7 +416,6 @@ class ExperimentListDict:
                     imageset.set_detector(detector, i)
                     imageset.set_goniometer(goniometer, i)
                     imageset.set_scan(scan, i)
-
             imageset.update_detector_px_mm_data()
 
         return imageset
@@ -870,9 +885,14 @@ class ExperimentListFactory:
         """Load an experiment list from a json file."""
         filename = os.path.abspath(filename)
         directory = os.path.dirname(filename)
-        with open(filename) as infile:
-            return ExperimentListFactory.from_json(
-                infile.read(), check_format=check_format, directory=directory
+        try:
+            with open(filename) as infile:
+                return ExperimentListFactory.from_json(
+                    infile.read(), check_format=check_format, directory=directory
+                )
+        except UnicodeDecodeError:
+            raise InvalidExperimentListError(
+                f"Cannot interpret {filename} as an ExperimentList"
             )
 
     @staticmethod
